You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@directory.apache.org by el...@apache.org on 2011/04/22 23:08:54 UTC

svn commit: r1096040 [2/2] - in /directory/shared/trunk: dsml/engine/src/main/java/org/apache/directory/shared/dsmlv2/engine/ dsml/parser/src/main/java/org/apache/directory/shared/dsmlv2/reponse/ dsml/parser/src/test/java/org/apache/directory/shared/ds...

Modified: directory/shared/trunk/ldap/model/src/main/java/org/apache/directory/shared/ldap/model/message/LdapResult.java
URL: http://svn.apache.org/viewvc/directory/shared/trunk/ldap/model/src/main/java/org/apache/directory/shared/ldap/model/message/LdapResult.java?rev=1096040&r1=1096039&r2=1096040&view=diff
==============================================================================
--- directory/shared/trunk/ldap/model/src/main/java/org/apache/directory/shared/ldap/model/message/extended/AddNoDResponse.java (original)
+++ directory/shared/trunk/ldap/model/src/main/java/org/apache/directory/shared/ldap/model/message/extended/AddNoDResponse.java Fri Apr 22 21:08:52 2011
@@ -72,7 +72,7 @@ public class AddNoDResponse extends AddR
                     ResultCodeEnum.PROTOCOL_ERROR, ResultCodeEnum.STRONG_AUTH_REQUIRED ) );
         }
 
-        super.getLdapResult().setErrorMessage( rcode.toString() + ": The server will disconnect!" );
+        super.getLdapResult().setDiagnosticMessage( rcode.toString() + ": The server will disconnect!" );
         super.getLdapResult().setMatchedDn( null );
         super.getLdapResult().setResultCode( rcode );
     }

Modified: directory/shared/trunk/ldap/model/src/main/java/org/apache/directory/shared/ldap/model/message/extended/BindNoDResponse.java
URL: http://svn.apache.org/viewvc/directory/shared/trunk/ldap/model/src/main/java/org/apache/directory/shared/ldap/model/message/extended/BindNoDResponse.java?rev=1096040&r1=1096039&r2=1096040&view=diff
==============================================================================
--- directory/shared/trunk/ldap/model/src/main/java/org/apache/directory/shared/ldap/model/message/extended/BindNoDResponse.java (original)
+++ directory/shared/trunk/ldap/model/src/main/java/org/apache/directory/shared/ldap/model/message/extended/BindNoDResponse.java Fri Apr 22 21:08:52 2011
@@ -72,7 +72,7 @@ public class BindNoDResponse extends Bin
                     ResultCodeEnum.PROTOCOL_ERROR, ResultCodeEnum.STRONG_AUTH_REQUIRED ) );
         }
 
-        super.getLdapResult().setErrorMessage( rcode.toString() + ": The server will disconnect!" );
+        super.getLdapResult().setDiagnosticMessage( rcode.toString() + ": The server will disconnect!" );
         super.getLdapResult().setMatchedDn( null );
         super.getLdapResult().setResultCode( rcode );
     }

Modified: directory/shared/trunk/ldap/model/src/main/java/org/apache/directory/shared/ldap/model/message/extended/CompareNoDResponse.java
URL: http://svn.apache.org/viewvc/directory/shared/trunk/ldap/model/src/main/java/org/apache/directory/shared/ldap/model/message/extended/CompareNoDResponse.java?rev=1096040&r1=1096039&r2=1096040&view=diff
==============================================================================
--- directory/shared/trunk/ldap/model/src/main/java/org/apache/directory/shared/ldap/model/message/extended/CompareNoDResponse.java (original)
+++ directory/shared/trunk/ldap/model/src/main/java/org/apache/directory/shared/ldap/model/message/extended/CompareNoDResponse.java Fri Apr 22 21:08:52 2011
@@ -72,7 +72,7 @@ public class CompareNoDResponse extends 
                     ResultCodeEnum.PROTOCOL_ERROR, ResultCodeEnum.STRONG_AUTH_REQUIRED ) );
         }
 
-        super.getLdapResult().setErrorMessage( rcode.toString() + ": The server will disconnect!" );
+        super.getLdapResult().setDiagnosticMessage( rcode.toString() + ": The server will disconnect!" );
         super.getLdapResult().setMatchedDn( null );
         super.getLdapResult().setResultCode( rcode );
     }

Modified: directory/shared/trunk/ldap/model/src/main/java/org/apache/directory/shared/ldap/model/message/extended/DeleteNoDResponse.java
URL: http://svn.apache.org/viewvc/directory/shared/trunk/ldap/model/src/main/java/org/apache/directory/shared/ldap/model/message/extended/DeleteNoDResponse.java?rev=1096040&r1=1096039&r2=1096040&view=diff
==============================================================================
--- directory/shared/trunk/ldap/model/src/main/java/org/apache/directory/shared/ldap/model/message/extended/DeleteNoDResponse.java (original)
+++ directory/shared/trunk/ldap/model/src/main/java/org/apache/directory/shared/ldap/model/message/extended/DeleteNoDResponse.java Fri Apr 22 21:08:52 2011
@@ -72,7 +72,7 @@ public class DeleteNoDResponse extends D
                     ResultCodeEnum.PROTOCOL_ERROR, ResultCodeEnum.STRONG_AUTH_REQUIRED ) );
         }
 
-        super.getLdapResult().setErrorMessage( rcode.toString() + ": The server will disconnect!" );
+        super.getLdapResult().setDiagnosticMessage( rcode.toString() + ": The server will disconnect!" );
         super.getLdapResult().setMatchedDn( null );
         super.getLdapResult().setResultCode( rcode );
     }

Modified: directory/shared/trunk/ldap/model/src/main/java/org/apache/directory/shared/ldap/model/message/extended/ExtendedNoDResponse.java
URL: http://svn.apache.org/viewvc/directory/shared/trunk/ldap/model/src/main/java/org/apache/directory/shared/ldap/model/message/extended/ExtendedNoDResponse.java?rev=1096040&r1=1096039&r2=1096040&view=diff
==============================================================================
--- directory/shared/trunk/ldap/model/src/main/java/org/apache/directory/shared/ldap/model/message/extended/ExtendedNoDResponse.java (original)
+++ directory/shared/trunk/ldap/model/src/main/java/org/apache/directory/shared/ldap/model/message/extended/ExtendedNoDResponse.java Fri Apr 22 21:08:52 2011
@@ -75,7 +75,7 @@ public class ExtendedNoDResponse extends
                     ResultCodeEnum.PROTOCOL_ERROR, ResultCodeEnum.STRONG_AUTH_REQUIRED ) );
         }
 
-        super.getLdapResult().setErrorMessage( rcode.toString() + ": The server will disconnect!" );
+        super.getLdapResult().setDiagnosticMessage( rcode.toString() + ": The server will disconnect!" );
         super.getLdapResult().setMatchedDn( null );
         super.getLdapResult().setResultCode( rcode );
     }

Modified: directory/shared/trunk/ldap/model/src/main/java/org/apache/directory/shared/ldap/model/message/extended/ModifyDnNoDResponse.java
URL: http://svn.apache.org/viewvc/directory/shared/trunk/ldap/model/src/main/java/org/apache/directory/shared/ldap/model/message/extended/ModifyDnNoDResponse.java?rev=1096040&r1=1096039&r2=1096040&view=diff
==============================================================================
--- directory/shared/trunk/ldap/model/src/main/java/org/apache/directory/shared/ldap/model/message/extended/ModifyDnNoDResponse.java (original)
+++ directory/shared/trunk/ldap/model/src/main/java/org/apache/directory/shared/ldap/model/message/extended/ModifyDnNoDResponse.java Fri Apr 22 21:08:52 2011
@@ -72,7 +72,7 @@ public class ModifyDnNoDResponse extends
                     ResultCodeEnum.PROTOCOL_ERROR, ResultCodeEnum.STRONG_AUTH_REQUIRED ) );
         }
 
-        super.getLdapResult().setErrorMessage( rcode.toString() + ": The server will disconnect!" );
+        super.getLdapResult().setDiagnosticMessage( rcode.toString() + ": The server will disconnect!" );
         super.getLdapResult().setMatchedDn( null );
         super.getLdapResult().setResultCode( rcode );
     }

Modified: directory/shared/trunk/ldap/model/src/main/java/org/apache/directory/shared/ldap/model/message/extended/ModifyNoDResponse.java
URL: http://svn.apache.org/viewvc/directory/shared/trunk/ldap/model/src/main/java/org/apache/directory/shared/ldap/model/message/extended/ModifyNoDResponse.java?rev=1096040&r1=1096039&r2=1096040&view=diff
==============================================================================
--- directory/shared/trunk/ldap/model/src/main/java/org/apache/directory/shared/ldap/model/message/extended/ModifyNoDResponse.java (original)
+++ directory/shared/trunk/ldap/model/src/main/java/org/apache/directory/shared/ldap/model/message/extended/ModifyNoDResponse.java Fri Apr 22 21:08:52 2011
@@ -72,7 +72,7 @@ public class ModifyNoDResponse extends M
                     ResultCodeEnum.PROTOCOL_ERROR, ResultCodeEnum.STRONG_AUTH_REQUIRED ) );
         }
 
-        super.getLdapResult().setErrorMessage( rcode.toString() + ": The server will disconnect!" );
+        super.getLdapResult().setDiagnosticMessage( rcode.toString() + ": The server will disconnect!" );
         super.getLdapResult().setMatchedDn( null );
         super.getLdapResult().setResultCode( rcode );
     }

Modified: directory/shared/trunk/ldap/model/src/main/java/org/apache/directory/shared/ldap/model/message/extended/NoticeOfDisconnect.java
URL: http://svn.apache.org/viewvc/directory/shared/trunk/ldap/model/src/main/java/org/apache/directory/shared/ldap/model/message/extended/NoticeOfDisconnect.java?rev=1096040&r1=1096039&r2=1096040&view=diff
==============================================================================
--- directory/shared/trunk/ldap/model/src/main/java/org/apache/directory/shared/ldap/model/message/extended/NoticeOfDisconnect.java (original)
+++ directory/shared/trunk/ldap/model/src/main/java/org/apache/directory/shared/ldap/model/message/extended/NoticeOfDisconnect.java Fri Apr 22 21:08:52 2011
@@ -146,7 +146,7 @@ public final class NoticeOfDisconnect ex
                     ResultCodeEnum.PROTOCOL_ERROR, ResultCodeEnum.STRONG_AUTH_REQUIRED ) );
         }
 
-        super.getLdapResult().setErrorMessage( rcode.toString() + ": The server will disconnect!" );
+        super.getLdapResult().setDiagnosticMessage( rcode.toString() + ": The server will disconnect!" );
         super.getLdapResult().setMatchedDn( null );
         super.getLdapResult().setResultCode( rcode );
     }

Modified: directory/shared/trunk/ldap/model/src/main/java/org/apache/directory/shared/ldap/model/message/extended/SearchNoDResponse.java
URL: http://svn.apache.org/viewvc/directory/shared/trunk/ldap/model/src/main/java/org/apache/directory/shared/ldap/model/message/extended/SearchNoDResponse.java?rev=1096040&r1=1096039&r2=1096040&view=diff
==============================================================================
--- directory/shared/trunk/ldap/model/src/main/java/org/apache/directory/shared/ldap/model/message/extended/SearchNoDResponse.java (original)
+++ directory/shared/trunk/ldap/model/src/main/java/org/apache/directory/shared/ldap/model/message/extended/SearchNoDResponse.java Fri Apr 22 21:08:52 2011
@@ -72,7 +72,7 @@ public class SearchNoDResponse extends S
                     ResultCodeEnum.PROTOCOL_ERROR, ResultCodeEnum.STRONG_AUTH_REQUIRED ) );
         }
 
-        super.getLdapResult().setErrorMessage( rcode.toString() + ": The server will disconnect!" );
+        super.getLdapResult().setDiagnosticMessage( rcode.toString() + ": The server will disconnect!" );
         super.getLdapResult().setMatchedDn( null );
         super.getLdapResult().setResultCode( rcode );
     }

Modified: directory/shared/trunk/ldap/model/src/test/java/org/apache/directory/shared/ldap/model/message/AbstractResultResponseTest.java
URL: http://svn.apache.org/viewvc/directory/shared/trunk/ldap/model/src/test/java/org/apache/directory/shared/ldap/model/message/AbstractResultResponseTest.java?rev=1096040&r1=1096039&r2=1096040&view=diff
==============================================================================
--- directory/shared/trunk/ldap/model/src/test/java/org/apache/directory/shared/ldap/model/message/AbstractResultResponseTest.java (original)
+++ directory/shared/trunk/ldap/model/src/test/java/org/apache/directory/shared/ldap/model/message/AbstractResultResponseTest.java Fri Apr 22 21:08:52 2011
@@ -23,13 +23,14 @@ package org.apache.directory.shared.ldap
 import static org.junit.Assert.assertFalse;
 import static org.junit.Assert.assertTrue;
 
-import com.mycila.junit.concurrent.Concurrency;
-import com.mycila.junit.concurrent.ConcurrentJunitRunner;
 import org.apache.directory.shared.ldap.model.exception.LdapException;
 import org.apache.directory.shared.ldap.model.name.Dn;
 import org.junit.Test;
 import org.junit.runner.RunWith;
 
+import com.mycila.junit.concurrent.Concurrency;
+import com.mycila.junit.concurrent.ConcurrentJunitRunner;
+
 
 /**
  * TestCase for the methods of the AbstractResultResponse class.
@@ -72,8 +73,8 @@ public class AbstractResultResponseTest
         LdapResult r0 = msg0.getLdapResult();
         LdapResult r1 = msg1.getLdapResult();
 
-        r0.setErrorMessage( "blah blah blah" );
-        r1.setErrorMessage( "blah blah blah" );
+        r0.setDiagnosticMessage( "blah blah blah" );
+        r1.setDiagnosticMessage( "blah blah blah" );
 
         r0.setMatchedDn( new Dn( "dc=example,dc=com" ) );
         r1.setMatchedDn( new Dn( "dc=example,dc=com" ) );
@@ -111,8 +112,8 @@ public class AbstractResultResponseTest
         LdapResult r0 = msg0.getLdapResult();
         LdapResult r1 = msg1.getLdapResult();
 
-        r0.setErrorMessage( "blah blah blah" );
-        r1.setErrorMessage( "blah blah blah" );
+        r0.setDiagnosticMessage( "blah blah blah" );
+        r1.setDiagnosticMessage( "blah blah blah" );
 
         r0.setMatchedDn( new Dn( "dc=example,dc=com" ) );
         r1.setMatchedDn( new Dn( "dc=apache,dc=org" ) );

Modified: directory/shared/trunk/ldap/model/src/test/java/org/apache/directory/shared/ldap/model/message/BindResponseImplTest.java
URL: http://svn.apache.org/viewvc/directory/shared/trunk/ldap/model/src/test/java/org/apache/directory/shared/ldap/model/message/BindResponseImplTest.java?rev=1096040&r1=1096039&r2=1096040&view=diff
==============================================================================
--- directory/shared/trunk/ldap/model/src/test/java/org/apache/directory/shared/ldap/model/message/BindResponseImplTest.java (original)
+++ directory/shared/trunk/ldap/model/src/test/java/org/apache/directory/shared/ldap/model/message/BindResponseImplTest.java Fri Apr 22 21:08:52 2011
@@ -20,15 +20,16 @@
 package org.apache.directory.shared.ldap.model.message;
 
 
-import com.mycila.junit.concurrent.Concurrency;
-import com.mycila.junit.concurrent.ConcurrentJunitRunner;
+import static org.junit.Assert.assertFalse;
+import static org.junit.Assert.assertTrue;
+
 import org.apache.directory.shared.ldap.model.exception.LdapException;
 import org.apache.directory.shared.ldap.model.name.Dn;
 import org.junit.Test;
 import org.junit.runner.RunWith;
 
-import static org.junit.Assert.assertFalse;
-import static org.junit.Assert.assertTrue;
+import com.mycila.junit.concurrent.Concurrency;
+import com.mycila.junit.concurrent.ConcurrentJunitRunner;
 
 
 /**
@@ -128,8 +129,8 @@ public class BindResponseImplTest
         LdapResultImpl r0 = new LdapResultImpl();
         LdapResultImpl r1 = new LdapResultImpl();
 
-        r0.setErrorMessage( "blah blah blah" );
-        r1.setErrorMessage( "blah blah blah" );
+        r0.setDiagnosticMessage( "blah blah blah" );
+        r1.setDiagnosticMessage( "blah blah blah" );
 
         r0.setMatchedDn( new Dn( "dc=example,dc=com" ) );
         r1.setMatchedDn( new Dn( "dc=example,dc=com" ) );
@@ -165,8 +166,8 @@ public class BindResponseImplTest
         LdapResultImpl r0 = new LdapResultImpl();
         LdapResultImpl r1 = new LdapResultImpl();
 
-        r0.setErrorMessage( "blah blah blah" );
-        r1.setErrorMessage( "blah blah blah" );
+        r0.setDiagnosticMessage( "blah blah blah" );
+        r1.setDiagnosticMessage( "blah blah blah" );
 
         r0.setMatchedDn( new Dn( "dc=example,dc=com" ) );
         r1.setMatchedDn( new Dn( "dc=example,dc=com" ) );

Modified: directory/shared/trunk/ldap/model/src/test/java/org/apache/directory/shared/ldap/model/message/LdapResultImplTest.java
URL: http://svn.apache.org/viewvc/directory/shared/trunk/ldap/model/src/test/java/org/apache/directory/shared/ldap/model/message/LdapResultImplTest.java?rev=1096040&r1=1096039&r2=1096040&view=diff
==============================================================================
--- directory/shared/trunk/ldap/model/src/test/java/org/apache/directory/shared/ldap/model/message/LdapResultImplTest.java (original)
+++ directory/shared/trunk/ldap/model/src/test/java/org/apache/directory/shared/ldap/model/message/LdapResultImplTest.java Fri Apr 22 21:08:52 2011
@@ -23,13 +23,14 @@ package org.apache.directory.shared.ldap
 import static org.junit.Assert.assertFalse;
 import static org.junit.Assert.assertTrue;
 
-import com.mycila.junit.concurrent.Concurrency;
-import com.mycila.junit.concurrent.ConcurrentJunitRunner;
 import org.apache.directory.shared.ldap.model.exception.LdapException;
 import org.apache.directory.shared.ldap.model.name.Dn;
 import org.junit.Test;
 import org.junit.runner.RunWith;
 
+import com.mycila.junit.concurrent.Concurrency;
+import com.mycila.junit.concurrent.ConcurrentJunitRunner;
+
 
 /**
  * Tests the methods of the LdapResultImpl class.
@@ -113,13 +114,13 @@ public class LdapResultImplTest
             }
 
 
-            public String getErrorMessage()
+            public String getDiagnosticMessage()
             {
                 return null;
             }
 
 
-            public void setErrorMessage( String a_errorMessage )
+            public void setDiagnosticMessage( String diagnosticMessage )
             {
             }
 
@@ -155,8 +156,8 @@ public class LdapResultImplTest
         LdapResultImpl r0 = new LdapResultImpl();
         LdapResultImpl r1 = new LdapResultImpl();
 
-        r0.setErrorMessage( "blah blah blah" );
-        r1.setErrorMessage( "blah blah blah" );
+        r0.setDiagnosticMessage( "blah blah blah" );
+        r1.setDiagnosticMessage( "blah blah blah" );
 
         r0.setMatchedDn( new Dn( "dc=example,dc=com" ) );
         r1.setMatchedDn( new Dn( "dc=example,dc=com" ) );
@@ -224,8 +225,8 @@ public class LdapResultImplTest
         LdapResultImpl r0 = new LdapResultImpl();
         LdapResultImpl r1 = new LdapResultImpl();
 
-        r0.setErrorMessage( "blah blah blah" );
-        r1.setErrorMessage( "blah blah blah" );
+        r0.setDiagnosticMessage( "blah blah blah" );
+        r1.setDiagnosticMessage( "blah blah blah" );
 
         r0.setMatchedDn( new Dn( "dc=example,dc=com" ) );
         r1.setMatchedDn( new Dn( "dc=example,dc=com" ) );
@@ -254,8 +255,8 @@ public class LdapResultImplTest
         LdapResultImpl r0 = new LdapResultImpl();
         LdapResultImpl r1 = new LdapResultImpl();
 
-        r0.setErrorMessage( "blah blah blah" );
-        r1.setErrorMessage( "blah" );
+        r0.setDiagnosticMessage( "blah blah blah" );
+        r1.setDiagnosticMessage( "blah" );
 
         r0.setMatchedDn( new Dn( "dc=example,dc=com" ) );
         r1.setMatchedDn( new Dn( "dc=example,dc=com" ) );
@@ -285,8 +286,8 @@ public class LdapResultImplTest
         LdapResultImpl r0 = new LdapResultImpl();
         LdapResultImpl r1 = new LdapResultImpl();
 
-        r0.setErrorMessage( "blah blah blah" );
-        r1.setErrorMessage( "blah blah blah" );
+        r0.setDiagnosticMessage( "blah blah blah" );
+        r1.setDiagnosticMessage( "blah blah blah" );
 
         r0.setMatchedDn( new Dn( "dc=example,dc=com" ) );
         r1.setMatchedDn( new Dn( "dc=apache,dc=org" ) );
@@ -316,8 +317,8 @@ public class LdapResultImplTest
         LdapResultImpl r0 = new LdapResultImpl();
         LdapResultImpl r1 = new LdapResultImpl();
 
-        r0.setErrorMessage( "blah blah blah" );
-        r1.setErrorMessage( "blah blah blah" );
+        r0.setDiagnosticMessage( "blah blah blah" );
+        r1.setDiagnosticMessage( "blah blah blah" );
 
         r0.setMatchedDn( new Dn( "dc=example,dc=com" ) );
         r1.setMatchedDn( new Dn( "dc=example,dc=com" ) );
@@ -347,8 +348,8 @@ public class LdapResultImplTest
         LdapResultImpl r0 = new LdapResultImpl();
         LdapResultImpl r1 = new LdapResultImpl();
 
-        r0.setErrorMessage( "blah blah blah" );
-        r1.setErrorMessage( "blah blah blah" );
+        r0.setDiagnosticMessage( "blah blah blah" );
+        r1.setDiagnosticMessage( "blah blah blah" );
 
         r0.setMatchedDn( new Dn( "dc=example,dc=com" ) );
         r1.setMatchedDn( new Dn( "dc=example,dc=com" ) );
--- directory/shared/trunk/ldap/model/src/main/java/org/apache/directory/shared/ldap/model/message/LdapResult.java (original)
+++ directory/shared/trunk/ldap/model/src/main/java/org/apache/directory/shared/ldap/model/message/LdapResult.java Fri Apr 22 21:08:52 2011
@@ -25,16 +25,69 @@ import org.apache.directory.shared.ldap.
 
 
 /**
- * LDAPv3 result structure embedded into Responses. See section 4.1.10 in <a
- * href="">RFC 2251</a> for a description of the LDAPResult ASN.1 structure,
- * here's a snippet from it:
+ * LDAPv3 result structure embedded into Responses. See section 4.1.9 in <a
+ * href="http://www.ietf.org/rfc/rfc4511.txt">RFC 4511</a> for a description of 
+ * the LDAPResult ASN.1 structure, here's a snippet from it:
  * 
  * <pre>
  *   The LDAPResult is the construct used in this protocol to return
- *   success or failure indications from servers to clients. In response
- *   to various requests servers will return responses containing fields
- *   of type LDAPResult to indicate the final status of a protocol
- *   operation request.
+ *   success or failure indications from servers to clients. To various
+ *  requests, servers will return responses containing the elements found
+ *  in LDAPResult to indicate the final status of the protocol operation
+ *  request.
+
+ * LDAPResult ::= SEQUENCE {
+ *     resultCode         ENUMERATED {
+ *         success                      (0),
+ *         operationsError              (1),
+ *         protocolError                (2),
+ *         timeLimitExceeded            (3),
+ *         sizeLimitExceeded            (4),
+ *         compareFalse                 (5),
+ *         compareTrue                  (6),
+ *         authMethodNotSupported       (7),
+ *         strongerAuthRequired         (8),
+ *              -- 9 reserved --
+ *         referral                     (10),
+ *         adminLimitExceeded           (11),
+ *         unavailableCriticalExtension (12),
+ *         confidentialityRequired      (13),
+ *         saslBindInProgress           (14),
+ *         noSuchAttribute              (16),
+ *         undefinedAttributeType       (17),
+ *         inappropriateMatching        (18),
+ *         constraintViolation          (19),
+ *         attributeOrValueExists       (20),
+ *         invalidAttributeSyntax       (21),
+ *              -- 22-31 unused --
+ *         noSuchObject                 (32),
+ *         aliasProblem                 (33),
+ *         invalidDNSyntax              (34),
+ *              -- 35 reserved for undefined isLeaf --
+ *         aliasDereferencingProblem    (36),
+ *              -- 37-47 unused --
+ *         inappropriateAuthentication  (48),
+ *         invalidCredentials           (49),
+ *         insufficientAccessRights     (50),
+ *         busy                         (51),
+ *         unavailable                  (52),
+ *         unwillingToPerform           (53),
+ *         loopDetect                   (54),
+ *              -- 55-63 unused --
+ *         namingViolation              (64),
+ *         objectClassViolation         (65),
+ *         notAllowedOnNonLeaf          (66),
+ *         notAllowedOnRDN              (67),
+ *         entryAlreadyExists           (68),
+ *         objectClassModsProhibited    (69),
+ *              -- 70 reserved for CLDAP --
+ *         affectsMultipleDSAs          (71),
+ *              -- 72-79 unused --
+ *         other                        (80),
+ *         ...  },
+ *     matchedDN          LDAPDN,
+ *     diagnosticMessage  LDAPString,
+ *     referral           [3] Referral OPTIONAL }
  * </pre>
  * 
  * @author <a href="mailto:dev@directory.apache.org">Apache Directory Project</a>
@@ -56,8 +109,7 @@ public interface LdapResult
      * Corresponds to the <b> resultCode </b> field within the LDAPResult ASN.1
      * structure.
      * 
-     * @param resultCode
-     *            the result code enum value.
+     * @param resultCode the result code enum value.
      */
     void setResultCode( ResultCodeEnum resultCode );
 
@@ -88,21 +140,21 @@ public interface LdapResult
 
 
     /**
      * Gets the descriptive error message associated with the error code. May be
      * null for SUCCESS, COMPARETRUE, COMPAREFALSE and REFERRAL operations.
      * 
      * @return the descriptive error message.
      */
-    String getErrorMessage();
+    String getDiagnosticMessage();
 
 
     /**
      * Sets the descriptive error message associated with the error code. May be
      * null for SUCCESS, COMPARETRUE, and COMPAREFALSE operations.
      * 
      * @param errorMessage the descriptive error message.
      */
-    void setErrorMessage( String errorMessage );
+    void setDiagnosticMessage( String diagnosticMessage );
 
 
     /**
@@ -118,7 +170,7 @@ public interface LdapResult
      * Gets the Referral associated with this LdapResult if the resultCode
      * property is set to the REFERRAL ResultCodeEnum.
      * 
-     * @return the referral on REFERRAL errors, null on all others.
+     * @return the referral on REFERRAL resultCode, null on all others.
      */
     Referral getReferral();
 
@@ -88,21 +140,21 @@ public interface LdapResult
 
     /**
-     * Gets the descriptive error message associated with the error code. May be
+     * Gets the descriptive diagnostic message associated with the error code. May be
      * null for SUCCESS, COMPARETRUE, COMPAREFALSE and REFERRAL operations.
      * 
@@ -88,21 +140,21 @@ public interface LdapResult
      * null for SUCCESS, COMPARETRUE, COMPAREFALSE and REFERRAL operations.
      * 
-     * @return the descriptive error message.
+     * @return the descriptive diagnostic message.
      */
@@ -88,21 +140,21 @@ public interface LdapResult
 
     /**
-     * Sets the descriptive error message associated with the error code. May be
+     * Sets the descriptive diagnostic message associated with the error code. May be
      * null for SUCCESS, COMPARETRUE, and COMPAREFALSE operations.
      * 
@@ -88,21 +140,21 @@ public interface LdapResult
      * null for SUCCESS, COMPARETRUE, and COMPAREFALSE operations.
      * 
-     * @param errorMessage the descriptive error message.
+     * @param diagnosticMessage the descriptive diagnostic message.
      */

Modified: directory/shared/trunk/ldap/model/src/main/java/org/apache/directory/shared/ldap/model/message/LdapResultImpl.java
URL: http://svn.apache.org/viewvc/directory/shared/trunk/ldap/model/src/main/java/org/apache/directory/shared/ldap/model/message/LdapResultImpl.java?rev=1096040&r1=1096039&r2=1096040&view=diff
==============================================================================
--- directory/shared/trunk/ldap/model/src/main/java/org/apache/directory/shared/ldap/model/message/LdapResultImpl.java (original)
+++ directory/shared/trunk/ldap/model/src/main/java/org/apache/directory/shared/ldap/model/message/LdapResultImpl.java Fri Apr 22 21:08:52 2011
@@ -24,22 +24,20 @@ import org.apache.directory.shared.ldap.
 
 
 /**
- * LdapResult implementation.
+ * The LdapResult implementation. RFC 4511 definition for a LdapResult is given below. <br>
  * 
  * @author <a href="mailto:dev@directory.apache.org">Apache Directory Project</a>
  */
 public class LdapResultImpl implements LdapResult
 {
-    static final long serialVersionUID = -1446626887394613213L;
-
     /** Lowest matched entry Dn - defaults to empty string */
     private Dn matchedDn;
 
     /** Referral associated with this LdapResult if the errorCode is REFERRAL */
     private Referral referral;
 
-    /** Decriptive error message - defaults to empty string */
-    private String errorMessage;
+    /** Decriptive diagnostic message - defaults to empty string */
+    private String diagnosticMessage;
 
     /** Resultant operation error code - defaults to SUCCESS */
     private ResultCodeEnum resultCode = ResultCodeEnum.SUCCESS;
@@ -48,45 +46,26 @@ public class LdapResultImpl implements L
     // ------------------------------------------------------------------------
     // LdapResult Interface Method Implementations
     // ------------------------------------------------------------------------
-
-
     /**
-     * Gets the descriptive error message associated with the error code. May be
-     * null for SUCCESS, COMPARETRUE, COMPAREFALSE and REFERRAL operations.
-     * 
-     * @return the descriptive error message.
+     * {@inheritDoc}
      */
-    public String getErrorMessage()
+    public String getDiagnosticMessage()
     {
-        return errorMessage;
+        return diagnosticMessage;
     }
 
 
     /**
-     * Sets the descriptive error message associated with the error code. May be
-     * null for SUCCESS, COMPARETRUE, and COMPAREFALSE operations.
-     * 
-     * @param errorMessage
-     *            the descriptive error message.
+     * {@inheritDoc}
      */
-    public void setErrorMessage( String errorMessage )
+    public void setDiagnosticMessage( String diagnosticMessage )
     {
-        this.errorMessage = errorMessage;
+        this.diagnosticMessage = diagnosticMessage;
     }
 
 
     /**
-     * Gets the lowest entry in the directory that was matched. For result codes
-     * of noSuchObject, aliasProblem, invalidDNSyntax and
-     * aliasDereferencingProblem, the matchedDN field is set to the name of the
-     * lowest entry (object or alias) in the directory that was matched. If no
-     * aliases were dereferenced while attempting to locate the entry, this will
-     * be a truncated form of the name provided, or if aliases were
-     * dereferenced, of the resulting name, as defined in section 12.5 of X.511
-     * [8]. The matchedDN field is to be set to a zero length string with all
-     * other result codes.
-     * 
-     * @return the Dn of the lowest matched entry.
+     * {@inheritDoc}
      */
     public Dn getMatchedDn()
     {
@@ -95,10 +74,7 @@ public class LdapResultImpl implements L
 
 
     /**
-     * Sets the lowest entry in the directory that was matched.
-     * 
-     * @see #getMatchedDn()
-     * @param matchedDn the Dn of the lowest matched entry.
+     * {@inheritDoc}
      */
     public void setMatchedDn( Dn matchedDn )
     {
@@ -107,11 +83,7 @@ public class LdapResultImpl implements L
 
 
     /**
-     * Gets the result code enumeration associated with the response.
-     * Corresponds to the <b> resultCode </b> field within the LDAPResult ASN.1
-     * structure.
-     * 
-     * @return the result code enum value.
+     * {@inheritDoc}
      */
     public ResultCodeEnum getResultCode()
     {
@@ -120,12 +92,7 @@ public class LdapResultImpl implements L
 
 
     /**
-     * Sets the result code enumeration associated with the response.
-     * Corresponds to the <b> resultCode </b> field within the LDAPResult ASN.1
-     * structure.
-     * 
-     * @param resultCode
-     *            the result code enum value.
+     * {@inheritDoc}
      */
     public void setResultCode( ResultCodeEnum resultCode )
     {
@@ -134,10 +101,7 @@ public class LdapResultImpl implements L
 
 
     /**
-     * Gets the Referral associated with this LdapResult if the resultCode
-     * property is set to the REFERRAL ResultCodeEnum.
-     * 
-     * @return the referral on REFERRAL errors, null on all others.
+     * {@inheritDoc}
      */
     public Referral getReferral()
     {
@@ -146,10 +110,7 @@ public class LdapResultImpl implements L
 
 
     /**
-     * Gets whether or not this result represents a Referral. For referrals the
-     * error code is set to REFERRAL and the referral property is not null.
-     * 
-     * @return true if this result represents a referral.
+     * {@inheritDoc}
      */
     public boolean isReferral()
     {
@@ -158,13 +119,7 @@ public class LdapResultImpl implements L
 
 
     /**
-     * Sets the Referral associated with this LdapResult if the resultCode
-     * property is set to the REFERRAL ResultCodeEnum. Setting this property
-     * will result in a true return from isReferral and the resultCode should be
-     * set to REFERRAL.
-     * 
-     * @param referral
-     *            optional referral on REFERRAL errors.
+     * {@inheritDoc}
      */
     public void setReferral( Referral referral )
     {
@@ -179,15 +134,19 @@ public class LdapResultImpl implements L
     public int hashCode()
     {
         int hash = 37;
+        
         if ( referral != null )
         {
             hash = hash * 17 + referral.hashCode();
         }
+        
         hash = hash * 17 + resultCode.hashCode();
-        if ( errorMessage != null )
+        
+        if ( diagnosticMessage != null )
         {
-            hash = hash * 17 + errorMessage.hashCode();
+            hash = hash * 17 + diagnosticMessage.hashCode();
         }
+        
         if ( matchedDn != null )
         {
             hash = hash * 17 + matchedDn.hashCode();
@@ -238,9 +197,9 @@ public class LdapResultImpl implements L
             return false;
         }
 
-        // Handle Error Messages where "" is considered equivalent to null
-        String errMsg0 = errorMessage;
-        String errMsg1 = result.getErrorMessage();
+        // Handle diagnostic Messages where "" is considered equivalent to null
+        String errMsg0 = diagnosticMessage;
+        String errMsg1 = result.getDiagnosticMessage();
 
         if ( errMsg0 == null )
         {
@@ -529,7 +488,7 @@ public class LdapResultImpl implements L
         }
 
         sb.append( "            Matched Dn : '" ).append( matchedDn ).append( "'\n" );
-        sb.append( "            Error message : '" ).append( errorMessage ).append( "'\n" );
+        sb.append( "            Diagnostic message : '" ).append( diagnosticMessage ).append( "'\n" );
 
         if ( referral != null )
         {

Modified: directory/shared/trunk/ldap/model/src/main/java/org/apache/directory/shared/ldap/model/message/extended/AddNoDResponse.java
URL: http://svn.apache.org/viewvc/directory/shared/trunk/ldap/model/src/main/java/org/apache/directory/shared/ldap/model/message/extended/AddNoDResponse.java?rev=1096040&r1=1096039&r2=1096040&view=diff
==============================================================================